@@ -23,7 +23,7 @@ from aliyunsdksae.endpoint import endpoint_data
 class DeleteIngressRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DeleteIngress')
+		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DeleteIngress','serverless')
 		self.set_uri_pattern('/pop/v1/sam/ingress/Ingress')
 		self.set_method('DELETE')
 		if hasattr(self, "endpoint_map"):
