@@ -23,7 +23,7 @@ from aliyunsdksae.endpoint import endpoint_data
 class DescribeApplicationStatusRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DescribeApplicationStatus')
+		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DescribeApplicationStatus','serverless')
 		self.set_uri_pattern('/pop/v1/sam/app/describeApplicationStatus')
 		self.set_method('GET')
 		if hasattr(self, "endpoint_map"):
